@@ -2,7 +2,7 @@ __title__ = 'restcord'
 __author__ = 'Lethys'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2020 (c) Lethys'
-__version__ = '0.0.4'
+__version__ = '0.0.5'
 
 from .ban import Ban
 from .channel import Channel
@@ -17,8 +17,9 @@ from .errors import (
     NotFound,
     RateLimited
 )
-from .guild import Guild
+from .guild import Guild, GuildPreview
 from .member import Member
 from .message import Message
 from .role import Role
 from .user import User
+from .voice import VoiceRegion
